<?php
namespace SM\Controller;

use SM\Controller\SMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\Sm00004006DocumentoContratoService;
use SM\Traits\TResponse;

class Sm00004006DocumentoContratoController extends SMCrud
{
    use TResponse;

    protected $ModeloDocumentoService;
    protected $documentoContratoService;

    public function __construct($crudService, $environment, Sm00004006DocumentoContratoService $documentoContratoService)
    {
        parent::__construct($crudService, $environment);
        $this->documentoContratoService=$documentoContratoService;
    }

    public function getDocumentoContrato()
    {
        try {
            $data = $this->documentoContratoService->getDocumentoContrato();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTabAnexoDocumentoContrato(Request $request)
    {
        try {
            $data = $this->documentoContratoService->getTabAnexoDocumentoContrato($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getContratosDocumento(Request $request)
    {
        try {
            $data = $this->documentoContratoService->getContratosDocumento($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirDocumentoContrato(DTO\Request $request)
    {
        try {
            $this->documentoContratoService->inserirDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function editarDocumentoContrato(DTO\Request $request)
    {
        try {
            $this->documentoContratoService->editarDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteDocumentoContrato(DTO\Request $request)
    {
        try {
            $this->documentoContratoService->deleteDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function inserirAnexoDocumentoContrato(Request $request)
    {
        try {
            $this->documentoContratoService->inserirAnexoDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function downloadAnexoModeloDocumentoContrato(Request $request)
    {
        $params = $request->getParameters();
        $idpadrao          = $params["idpadrao"];
        $nrcontratodocidioma = $params["nrcontratodocidioma"];
        $nrseqcontdoc    = $params["nrseqcontdoc"];
        $this->documentoContratoService->downloadAnexoModeloDocumentoContrato($idpadrao, $nrcontratodocidioma, $nrseqcontdoc);
    }

    public function deletarAnexoModeloDocumentoContrato(Request $request)
    {
        try {
            $this->documentoContratoService->limparAnexoModeloDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletarAnexoDocumentoContrato(DTO\Request $request)
    {
        try {
            $this->documentoContratoService->deletarAnexoDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
    
    public function atualizarAnexoModeloDocumentoContrato(Request $request)
    {
        try {
            $this->documentoContratoService->atualizarAnexoModeloDocumentoContrato($request->getParameters());
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getParceiroNegocioContrato()
    {
        try {
            $data = $this->documentoContratoService->getParceiroNegocioContrato();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getNomeContrato()
    {
        try {
            $data = $this->documentoContratoService->getNomeContrato();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
