<?php

namespace SM\Service;

use SM\Factory\ProposalModelFactory;
use SM\Service\FindService;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use SM\Service\FileServerService;
use SM\Util\Utilities;
use Doctrine\ORM\EntityManager;

class ProposalModelService
{
    protected $ProposalModelFactory;
    protected $findService;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(EntityManager $entityManager, ProposalModelFactory $ProposalModelFactory, FindService $findService, Environment $Environment, NewCode $newCode)
    {
        $this->connection               = $entityManager->getConnection();
        $this->ProposalModelFactory     = $ProposalModelFactory;
        $this->findService              = $findService;
        $this->Environment              = $Environment;
        $this->newCode                  = $newCode;
    }

    public function getProposalModel()
    {
        return $this->ProposalModelFactory->getProposalModel();
    }

    public function getTabEscopoFaturamentoProposal($params)
    {
        $params = array(
            "NRORCAMENTOMODELO"   => $params['NRORCAMENTOMODELO']
        );
        return $this->ProposalModelFactory->getTabEscopoFaturamentoProposal($params);
    } 

    public function getEscopoFaturamentoModeloDoc($params)
    {
        $params = array(
            "NRRELACESCOPOMODELO"   => $params['NRRELACESCOPOMODELO']
        );
        return $this->ProposalModelFactory->getEscopoFaturamentoModeloDoc($params);
    }

    /**
     * Valida se o usuário está tentando inserir uma situação existente
    **/
    public function validarExistenciaIdsituacao($row, $nrorg, $idSituacao){
        try {
            
            $params = array(
                "NRRELACESCOPOMODELO" => $row["NRRELACESCOPOMODELO"],
                "NRSEQMODDOCFCT"      => $row["NRSEQMODDOCFCT"],
                "NRORG"               => $nrorg
            );

            $existe = $this->ProposalModelFactory->getModeloDocumentoSituacao($idSituacao, $params);

            if(count($existe) > 0 && $existe[0]["IDSITUACAOORCAMENTO"]) {
                $situacoes = "SITUACAO_JA_CADASTRADA::" . $existe[0]["IDSITUACAOORCAMENTO"];
                $situacoes = str_replace('ELABORACAO',  'Em Elaboração',     $situacoes);
                $situacoes = str_replace('CONCLUIDO',   'Concluída',         $situacoes);
                $situacoes = str_replace('ACEITO',      'Aceita',            $situacoes);
                $situacoes = str_replace('CANCELADO',   'Cancelada',         $situacoes);
                $situacoes = str_replace('ENVIADO',     'Documento Enviado', $situacoes);
                throw new \Exception($situacoes);
            }
            
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function saveEscopoFaturamentoModeloDoc($row)
    {
        $this->connection->beginTransaction();

        try {

            $nrorg = $this->Environment->getNrOrg();
            $cdoperador = $this->Environment->getCdOperador();

            if ($row['NRORCAESCOPODOC'] == null) {
                
                foreach($row["IDSITUACAOORCAMENTOEDIT"] as $idSituacao) {
                    $this->validarExistenciaIdsituacao($row, $nrorg, $idSituacao);
                    $nrorcaescopodoc = $this->newCode->getCodeByTableName("FCT_ORCAESCOPODOC", $nrorg, 1, 10, true);
                    $params = array(
                        "NRORCAESCOPODOC"     => $nrorcaescopodoc,
                        "NRRELACESCOPOMODELO" => $row["NRRELACESCOPOMODELO"],
                        "NRSEQMODDOCFCT"      => $row["NRSEQMODDOCFCT"],
                        "IDPERMITEDOCX"       => $row["IDPERMITEDOCX"],
                        "IDATIVO"             => 'S',
                        "NRORG"               => $nrorg,
                        "IDSITUACAOORCAMENTO" => $idSituacao,
                        "CDOPERADOR"          => $cdoperador
                    );

                    $this->ProposalModelFactory->inserirDocumentoSituacao($params);
                } 
            } else {
                
                $idsitadicionadas = array_diff($row["IDSITUACAOORCAMENTOEDIT"], $row["IDSITUACAOORCAMENTO"]);
                $idsitremovidas = array_diff($row["IDSITUACAOORCAMENTO"], $row["IDSITUACAOORCAMENTOEDIT"]);
                
                if (count($idsitadicionadas) > 0) {

                    foreach($idsitadicionadas as $idSituacao) {
                        $this->validarExistenciaIdsituacao($row, $nrorg, $idSituacao);
                        $nrorcaescopodoc = $this->newCode->getCodeByTableName("FCT_ORCAESCOPODOC", $nrorg, 1, 10, true);
                        $params = array(
                            "NRORCAESCOPODOC"     => $nrorcaescopodoc,
                            "NRRELACESCOPOMODELO" => $row["NRRELACESCOPOMODELO"],
                            "NRSEQMODDOCFCT"      => $row["NRSEQMODDOCFCT"],
                            "IDPERMITEDOCX"       => $row["IDPERMITEDOCX"],
                            "IDATIVO"             => 'S',
                            "NRORG"               => $nrorg,
                            "IDSITUACAOORCAMENTO" => $idSituacao,
                            "CDOPERADOR"          => $cdoperador
                        );

                        $this->ProposalModelFactory->inserirDocumentoSituacao($params);
                    }
                }

                if (count($idsitremovidas) > 0) {

                    foreach($idsitremovidas as $idSituacao) {
                        
                        $params = array(
                            "NRRELACESCOPOMODELO" => $row["NRRELACESCOPOMODELO"],
                            "NRORG"               => $nrorg,
                        );

                        $this->ProposalModelFactory->excluirDocumentoSituacao($idSituacao, $params);
                    }
                }

                if ((count($idsitremovidas) == 0) && (count($idsitadicionadas) == 0)) {
                    $params = array(
                        "NRSEQMODDOCFCT"      => $row["NRSEQMODDOCFCT"],
                        "NRRELACESCOPOMODELO" => $row["NRRELACESCOPOMODELO"],
                        "IDPERMITEDOCX"       => $row["IDPERMITEDOCX"],
                        "NRORG"               => $nrorg,
                        "CDOPERADOR"          => $cdoperador
                    );

                    $this->ProposalModelFactory->editarDocumentoSituacao($params);
                }
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getTabComposicoes($params)
    {
        $params = array(
            "NRORCAMENTOMODELO"   => $params['NRORCAMENTOMODELO']
        );
    
        return $this->ProposalModelFactory->getTabComposicoes($params);
    }

    public function getTabItens($params)
    {
        $params = array(
            "NRORCAMENTOMODELO"   => $params['NRORCAMENTOMODELO']
        );
    
        return $this->ProposalModelFactory->getTabItens($params);
    }

    public function getTabPerfisAcessoProposal($params)
    {
        $params = array(
            "NRORCAMENTOMODELO"   => $params['NRORCAMENTOMODELO']
        );
        return $this->ProposalModelFactory->getTabPerfisAcessoProposal($params);
    }

    public function getTabSignatariosPadroesProposal($params)
    {
        $params = array(
            "NRORCAMENTOMODELO"   => $params['NRORCAMENTOMODELO']
        );
        return $this->ProposalModelFactory->getTabSignatariosPadroesProposal($params);
    }

    public function getServicoProduto()
    {
        return $this->ProposalModelFactory->getServicoProduto();
    }

    public function getTipoMedidaProposal()
    {
        return $this->ProposalModelFactory->getTipoMedidaProposal();
    }

    public function saveModalAddProposalModel($params)
    {
        $this->connection->beginTransaction();

        try {

            $nrorg = $this->Environment->getNrOrg();
            $cdoperador = $this->Environment->getCdOperador();
            $nrorcamentomodelo = $this->newCode->getCodeByTableName("FCT_ORCAMENTOMODELO", $nrorg, 1, 10, true);

            $dataParams = array(
                "NRORCAMENTOMODELO"         => $nrorcamentomodelo,
                "IDATIVO"                   => $params["IDATIVO"],  
                "IDBLOQALTERADADOS"         => $params["IDBLOQALTERADADOS"],
                "IDFATURACONTR"             => "A",
                "NMORCAMENTOMODELO"         => $params["NMORCAMENTOMODELO"],  
                "QTDIASVALIDADE"            => $params["QTDIASVALIDADE"],  
                "QTDIASCONTRATO"            => $params["QTDIASCONTRATO"],  
                "IDUTILIZACOMP"             => $params["IDUTILIZACOMP"],  
                "NRDIASCARENCIA"            => $params["NRDIASCARENCIA"],  
                "IDOBRIGAOPORTUNIDADE"      => $params["IDOBRIGAOPORTUNIDADE"],  
                "NRSEQMODCONTRA"            => $params["NRSEQMODCONTRA"],  
                "CDMINEMORCA"               => $params["CDMINEMORCA"],  
                "IDUTILIZAREVENDA"          => $params["IDUTILIZAREVENDA"],  
                "DSREFERENCIAORCA"          => $params["DSREFERENCIAORCA"],  
                "DSOBSERVACAOORCA"          => $params["DSOBSERVACAOORCA"],  
                "IDASSELETRDIGITAL"         => $params["IDASSELETRDIGITAL"],  
                "IDENVIADOCCONCLUSAO"       => $params["IDENVIADOCCONCLUSAO"],  
                "NRTIPODOCCERTSIGN"         => $params["NRTIPODOCCERTSIGN"],  
                "IDENVIADOCOPERRESPCONCASS" => $params["IDENVIADOCOPERRESPCONCASS"],
                "NRORG"                     => $nrorg,
                "CDOPERINCLUSAO"            => $cdoperador,
            );

            $this->ProposalModelFactory->saveModalAddProposalModel($dataParams);

            if ($params["IDASSELETRDIGITAL"] == "S") {
                $this->insereSignatariosPadroesOrca($dataParams);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    /**
     * insere os signatários padrões de modelo de proposta que foram buscados na parametrização SM 
    **/
    public function insereSignatariosPadroesOrca($parametros){
        try {

            $params = array(
                "NRORG"   => $parametros["NRORG"]
            );

            $certsign = $this->ProposalModelFactory->validaTokenCertsign($params);

            
            if(count($certsign) > 0) {

                $params = array(
                    "NRORG"   => $parametros["NRORG"]
                );

                $signatarios = $this->ProposalModelFactory->buscaSignatariosPadroes($params);

                if(count($signatarios) > 0) {
                
                  foreach($signatarios as $signatario){
                      
                       $params = array(
                           "NRORCAMENTOMODELO" => $parametros["NRORCAMENTOMODELO"],
                           "NRPARCNEGOCIO"     => $signatario["NRPARCNEGOCIO"],
                           "IDTPSIGNATARIO"    => $signatario["IDTPSIGNATARIO"],
                           "NRORG"             => $parametros["NRORG"]
                       );
                      
                       $valida = $this->ProposalModelFactory->validaSignatCadastrados($params);
                      
                       if ($valida == 0){
                      
                          $nrsignatpadrorca = $this->newCode->getCodeByTableName("FCT_SIGNATPADRMODORCA", $parametros["NRORG"], 1, 10, true);
                          
                          $params= array(
                              "NRSIGNATPADRORCA"   => $nrsignatpadrorca,
                              "NRORCAMENTOMODELO"  => $parametros["NRORCAMENTOMODELO"],
                              "NRPARCNEGOCIO"      => $signatario["NRPARCNEGOCIO"], 
                              "IDTIPOASSINATURA"   => $signatario["IDTIPOASSINATURA"], 
                              "IDTESTEMUNHA"       => $signatario["IDTESTEMUNHA"], 
                              "NRORDENACAO"        => $signatario["NRORDENACAO"], 
                              "IDTPSIGNATARIO"     => $signatario["IDTPSIGNATARIO"],
                              "DSEMAILNOTSIGNENV"  => $signatario["DSEMAILNOTSIGNENV"], 
                              "DSEMAILNOTIFOUTROS" => $signatario["DSEMAILNOTIFOUTROS"],
                              "NRORG"              => $parametros["NRORG"],
                              "OPERADOR"           => $parametros["CDOPERINCLUSAO"]
                          );

                          $signatarios = $this->ProposalModelFactory->insereSignatariosPadroes($params);
                           
                          $params = array(
                              "NRSIGNATARIOSPADR" => $signatario["NRSIGNATARIOSPADR"],
                              "NRORG"             => $parametros["NRORG"],
                          ); 
                          
                          $operadores = $this->ProposalModelFactory->buscaOperadoresNotif($params);
                                
                          foreach($operadores as $cdoperador){
                             
                             $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);

                             $params = array(
                                "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                                "NRSIGNATPADRORCA"     => $nrsignatpadrorca,
                                "CDOPERADOR"           => $cdoperador["CDOPERADOR"], 
                                "NRORG"                => $parametros["NRORG"],
                                "CDOPERAINCLUSAO"      => $parametros["CDOPERINCLUSAO"]
                             );
                            
                             $this->ProposalModelFactory->insereOperadoresNotifica($params);
                          }
                       }
                    }      
                }  
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function deleteProposalModel($parametros)
    {
        $this->connection->beginTransaction();

        try {
            $retorno = $this->findService->formatarArray($parametros["NRS"]);
            $this->ProposalModelFactory->deleteProposalModel($retorno);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteProposalModelTabEscopoFaturamento($parametros)
    {
        $this->connection->beginTransaction();

        try {
            $retorno = $this->findService->formatarArray($parametros["NRS"]);
            $this->ProposalModelFactory->deleteProposalModelTabEscopoFaturamento($retorno);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteProposalModelTabEscFatModeloDocumento($parametros)
    {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach($parametros["NRS"] as $item){

                $params = array(
                    "NRRELACESCOPOMODELO"   => $item["NRRELACESCOPOMODELO"],
                    "NRSEQMODDOCFCT"        => $item["NRSEQMODDOCFCT"], 
                    "NRORG"                 => $nrorg,
                );

                $this->ProposalModelFactory->excluirEscFatModeloDocumento($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteProposalModelTabComposicoes($parametros)
    {
        $this->connection->beginTransaction();

        try {
            if (isset($parametros["NRS"])) {
                $retorno = $this->findService->formatarArray($parametros["NRS"]);
                $retorno = str_replace("'", "", $retorno);
            } else {
                $retorno = $parametros;
            }

            $this->ProposalModelFactory->deleteProposalModelTabComposicoes($retorno);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteProposalModelTabPerfisAcesso($parametros)
    {
        $this->connection->beginTransaction();

        try {
            $retorno = $this->findService->formatarArray($parametros["NRS"]);
            $this->ProposalModelFactory->deleteProposalModelTabPerfisAcesso($retorno);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteProposalModelTabSignatariosPadroes($parametros)
    {
        $this->connection->beginTransaction();

        try {
            if (isset($parametros["NRSIGNATPADRCONT"])) {
                $retorno = $this->findService->formatarArray($parametros["NRSIGNATPADRCONT"]);
            } else {
                $retorno = $parametros;
            }
            
            $this->ProposalModelFactory->deleteProposalModelTabSignatariosPadroes($retorno);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getEscopoDeFaturamentoProposal()
    {
        return $this->ProposalModelFactory->getEscopoDeFaturamentoProposal();
    }

    public function getModeloContratoProposal()
    {
        return $this->ProposalModelFactory->getModeloContratoProposal();
    }

    /**
     * A função "validaEscopoProposta" verifica se o escopo 
     * que está sendo relacionado já está relacionado ao modelo.
     */
     
     public function validaEscopoProposta($tipoOrcamento, $orcaModelo){
    
        $paramsValidaEscopoProp = array(
            "NRTIPOORCAMENTO"   => $tipoOrcamento,
            "NRORCAMENTOMODELO" => $orcaModelo,
            "NRORG"             => $this->Environment->getNrOrg()
        );
        
        $returnValidaEscopoProp = $this->ProposalModelFactory->validaEscopoProposta($paramsValidaEscopoProp);
        
        return $returnValidaEscopoProp[0]["VALIDAESCOPO"] != 0;
        
    }

    public function saveModalAddProposalModelTabEscopoFaturamento($params)
    {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrOrg();
            $cdoperador = $this->Environment->getCdOperador();
            $orcaModelo = $params["NRORCAMENTOMODELO"];

            foreach($params["NRTIPOORCAMENTO"] as $tipoOrcamento) {
                $existe = $this->validaEscopoProposta($tipoOrcamento, $orcaModelo);

                if (!$existe) {
                    $nrrelacescopomodelo = $this->newCode->getCodeByTableName("FCT_RELACESCOPOMODELO", $nrorg, 1, 10, true);

                    $this->ProposalModelFactory->saveModalAddProposalModelTabEscopoFaturamento(array(
                        "NRORCAMENTOMODELO"          => $params["NRORCAMENTOMODELO"],
                        "NRTIPOORCAMENTO"            => $tipoOrcamento,
                        "IDVERIFICADOC"              => $params["IDVERIFICADOC"],   
                        "NRRELACESCOPOMODELO"        => $nrrelacescopomodelo,
                        "IDATIVO"                    => "S",
                        "NRORG"                      => $nrorg,
                        "CDOPERINCLUSAO"             => $cdoperador,
                    ));
                } else {
                    throw new \Exception("EXISTE!");
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function saveModalAddProposalModelTabComposicoes($params)
    {
        $this->connection->beginTransaction();
        try {
            $CDOPERADOR = $this->Environment->getCdOperador();
            $NRORG = $this->Environment->getNrOrg();
            $NRRELORCAMODCOMP = $this->newCode->getCodeByTableName("FCT_RELORCAMODCOMPOSICAO", $NRORG, 1, 10, true);

            $this->ProposalModelFactory->saveModalAddProposalModelTabComposicoes(array(
                "NRRELORCAMODCOMP"           => $NRRELORCAMODCOMP,
                "NRORCAMENTOMODELO"          => $params["NRORCAMENTOMODELO"],
                "NRCOMPSERVICO"              => $params["NRCOMPSERVICO"],
                "IDATIVO"                    => "S",
                "NRORG"                      => $NRORG,
                "CDOPERINCLUSAO"             => $CDOPERADOR,
                "CDOPERULTATU"               => $CDOPERADOR,
            ));

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function saveModalAddProposalModelTabPerfisAcesso($params)
    {
        $this->connection->beginTransaction();

        try {
            $NRORG = $this->Environment->getNrOrg();
            $NRRELORCAMODPERFACESS = $this->newCode->getCodeByTableName("FCT_RELORCAMODPERFACESS", $NRORG, 1, 10, true);

            $this->ProposalModelFactory->saveModalAddProposalModelTabPerfisAcesso(array(
                "NRORCAMENTOMODELO"          => $params["NRORCAMENTOMODELO"],
                "IDATIVO"                    => "S",
                "NRPERFILACESSO"             => $params["NRPERFILACESSO"],
                "NRORG"                      => $NRORG,
                "CDOPERINCLUSAO"             => $this->Environment->getCdOperador(),
                "NRRELORCAMODPERFACESS"      => $NRRELORCAMODPERFACESS,
            ));
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function saveModalAddProposalModelTabSignatariosPadroes($params)
    {
        $this->connection->beginTransaction();

        try {
            $NRORG = $this->Environment->getNrOrg();
            $NRSIGNATPADRCONT = $this->newCode->getCodeByTableName("FCT_SIGNATPADRMODCONT", $NRORG, 1, 10, true);
            $DSEMAILNOTSIGNENV = $this->findService->formatarArray($params["DSEMAILNOTSIGNENV"]);
            $DSEMAILNOTSIGNENV = str_replace("'", "", $DSEMAILNOTSIGNENV);
            $DSEMAILNOTSIGNENV = str_replace(",", "_", $DSEMAILNOTSIGNENV);

            $this->ProposalModelFactory->saveModalAddProposalModelTabSignatariosPadroes(array(
                "NRSIGNATPADRCONT"           => $NRSIGNATPADRCONT,
                "NRSEQMODCONTRA"             => $params["NRSEQMODCONTRA"],
                "IDTPSIGNATARIO"             => $params["IDTPSIGNATARIO"],
                "NRPARCNEGOCIO"              => $params["NRPARCNEGOCIO"],
                "IDTIPOASSINATURA"           => $params["IDTIPOASSINATURA"],
                "IDTESTEMUNHA"               => $params["IDTESTEMUNHA"],
                "NRORDENACAO"                => $params["NRORDENACAO"],
                "DSEMAILNOTSIGNENV"          => $DSEMAILNOTSIGNENV,
                "DSEMAILNOTIFOUTROS"         => $params["DSEMAILNOTIFOUTROS"],
                "NRORG"                      => $NRORG,
                "CDOPERINCLUSAO"             => $this->Environment->getCdOperador(),
                "IDATIVO"                    => "S"
            ));

            foreach ($params["CDOPERADOR"] as $CDOPERADOR) {
                $NRRELOPERNOTIFASSELE = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $NRORG, 1, 10, true);
                $this->ProposalModelFactory->saveOperadoresSigPadrao(array(
                    "NRRELOPERNOTIFASSELE"   => $NRRELOPERNOTIFASSELE,
                    "NRSIGNATPADRCONT"       => $NRSIGNATPADRCONT,
                    "CDOPERADOR"             => $CDOPERADOR,
                    "NRORG"                  => $NRORG,
                    "CDOPERINCLUSAO"         => $this->Environment->getCdOperador(),
                    "IDATIVO"                => "S"
                ));
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getComposicoes()
    {
        return $this->ProposalModelFactory->getComposicoes();
    }

    public function getTipoDocCertsign()
    {
        return $this->ProposalModelFactory->getTipoDocCertsign();
    }

    public function getPerfisDeAcessoProposal()
    {
        return $this->ProposalModelFactory->getPerfisDeAcessoProposal();
    }

    public function getSignatariosProposalModel()
    {
        return $this->ProposalModelFactory->getSignatariosProposalModel();
    }

    public function getOperadoresProposalModel()
    {
        return $this->ProposalModelFactory->getOperadoresProposalModel();
    }

    public function getCpfSignatario($params)
    {
        $params = array(
            "NRPARCNEGOCIO"   => $params['signatario']
        );
        return $this->ProposalModelFactory->getCpfSignatario($params);
    }

    public function editProposalModelViewItens($params)
    {
        $this->connection->beginTransaction();
       
        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();

            $this->deleteProposalModelTabSignatariosPadroes($params['NRSIGNATPADRCONT']);
            $this->saveModalAddProposalModelTabSignatariosPadroes($params);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function editProposalModelTabSignatariosPadroes($params)
    {
        $this->connection->beginTransaction();
       
        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();

            $this->deleteProposalModelTabSignatariosPadroes($params['NRSIGNATPADRCONT']);
            $this->saveModalAddProposalModelTabSignatariosPadroes($params);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function editProposalModel($params)
    {
        $this->connection->beginTransaction();

        try {
            $nrorg = $this->Environment->getNrOrg();
            $cdoperador = $this->Environment->getCdOperador();
 
            $this->ProposalModelFactory->editProposalModel(array(
                "NRORCAMENTOMODELO"          => $params["NRORCAMENTOMODELO"],
                "IDATIVO"                    => $params["IDATIVO"],
                "IDBLOQALTERADADOS"          => $params["IDBLOQALTERADADOS"],
                "NMORCAMENTOMODELO"          => $params["NMORCAMENTOMODELO"],
                "QTDIASVALIDADE"             => $params["QTDIASVALIDADE"],
                "QTDIASCONTRATO"             => $params["QTDIASCONTRATO"],
                "IDUTILIZACOMP"              => $params["IDUTILIZACOMP"],
                "NRDIASCARENCIA"             => $params["NRDIASCARENCIA"],
                "IDOBRIGAOPORTUNIDADE"       => $params["IDOBRIGAOPORTUNIDADE"],
                "NRSEQMODCONTRA"             => $params["NRSEQMODCONTRA"],
                "CDMINEMORCA"                => $params["CDMINEMORCA"],
                "IDUTILIZAREVENDA"           => $params["IDUTILIZAREVENDA"],
                "DSREFERENCIAORCA"           => $params["DSREFERENCIAORCA"],
                "DSOBSERVACAOORCA"           => $params["DSOBSERVACAOORCA"],
                "IDASSELETRDIGITAL"          => $params["IDASSELETRDIGITAL"],
                "IDENVIADOCCONCLUSAO"        => $params["IDENVIADOCCONCLUSAO"],
                "NRTIPODOCCERTSIGN"          => $params["NRTIPODOCCERTSIGN"],
                "IDENVIADOCOPERRESPCONCASS"  => $params["IDENVIADOCOPERRESPCONCASS"],
                "NRORG"                      => $nrorg,
                "CDOPERULTATU"               => $cdoperador,
            ));
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
