<?php

namespace SM\Service;

use SM\Factory\Sm00052002DescontoMaximoServicoPerfilAcessoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00052002DescontoMaximoServicoPerfilAcessoService
{
    protected $connection;
    protected $descMaximoServicoFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00052002DescontoMaximoServicoPerfilAcessoFactory $descMaximoServicoFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->descMaximoServicoFactory     = $descMaximoServicoFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getNomePerfilAcessoDescontoMaximoServico()
    {
        return $this->descMaximoServicoFactory->getNomePerfilAcessoDescontoMaximoServico();
    }

    public function getServicoDescontoMaximoServicoPerfilAcesso($params)
    {

        $parametros = array(
            "NRPERFILACESSO" => $params['NRPERFILACESSO']
        );
    
        return $this->descMaximoServicoFactory->getServicoDescontoMaximoServicoPerfilAcesso($parametros);
    }
    
    public function saveDescMaxServicoPerfilAcesso($params)
    {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        $this->connection->beginTransaction();
    
        try {
            foreach ($params as $row) {
                $paramsaux = array(
                    "NRPERFILACESSO" => $row['NRPERFILACESSO'],
                    "CDSERVORCA" => $row['CDSERVORCA'],
                    "NRSEQDESCPERF" => $row['NRSEQDESCPERF'],
                );
                $valida = $this->descMaximoServicoFactory->validaDados($paramsaux);
                if ($valida == 0) {
                    if ($row["NRSEQDESCPERF"]) {
                        $parametros = array(
                            "NRPERFILACESSO"             => $row['NRPERFILACESSO'],
                            "CDSERVORCA"                 => $row['CDSERVORCA'],
                            "VRPERCENTUAL"               => $row['VRPERCENTUAL'],
                            "NRORG"                      => $nrorg,
                            "IDATIVO"                    => "S",
                            "CDOPERULTATU"               => $cdoperador,
                            "NRSEQDESCPERF"              => $row['NRSEQDESCPERF']
                        );
                        $this->descMaximoServicoFactory->updateDescMaxServicoPerfilAcesso($parametros);
                    } else {
                        $nrdescmaxservico = $this->newCode->getCodeByTableName("FCT_PERCDESCOPER", $nrorg, 1, 10, true);
                        $parametros = array(
                            "NRSEQDESCPERF"          => $nrdescmaxservico,
                            "NRPERFILACESSO"         => $row['NRPERFILACESSO'],
                            "CDSERVORCA"             => $row['CDSERVORCA'],
                            "VRPERCENTUAL"           => $row['VRPERCENTUAL'],
                            "NRORG"                  => $nrorg,
                            "IDATIVO"                => "S",
                            "CDOPERINCLUSAO"         => $cdoperador
                        );
                        $this->descMaximoServicoFactory->insertDescMaxServicoPerfilAcesso($parametros);
                    }
                } else {
                    throw new \Exception("ERRO");
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteDescMaxServicoModalServicoPerfilAcesso($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $chave => $desconto) {
                $dataParam = array(
                    "NRSEQDESCPERF" => $desconto["NRSEQDESCPERF"],
                );
                $this->descMaximoServicoFactory->deleteDescMaxServicoModalServicoPerfilAcesso($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
